import { L as LoggerService } from './el-result-BYk3F9qI.js';
import { I as IOSubjectRPC, M as MessagePortSubject, e as Subject, R as REGION, t as taskStatusBroadcast, h as ENV_KEY } from './message-g8wSSm3N.js';
import { d as defineDriver, b as createStorage, s as setupWebExtensionOAuth, e as createFetch, i as instance, S as STORAGE, F as FETCH, L as LOGGER, f as FONT_SETTINGS_SERVICE, R as REGION$1, U as UploaderService, h as FilesService, j as RecorderDB, k as storageObservable } from './fetch-BWmuaPuD.js';
import './browser-polyfill-BkiQUeYD.js';
import './index-hZERwo9M.js';
import { O as OFFSCREEN_RPC_MAGIC, a as OFFSCREEN_CONNECT } from './constants-DQdSyCS5.js';
import './vue-i18n.runtime-BBVXiHAN.js';
import './interval-BgVj3k04.js';

const UnstorageDriverRpc = defineDriver((opts)=>{
    const { rpc, change$ } = opts;
    return {
        name: 'storage.rpc',
        options: opts,
        hasItem (key) {
            return rpc.invoke('storageHasItem', key);
        },
        getItem (key) {
            return rpc.invoke('storageGetItem', key);
        },
        setItem (key, value) {
            return rpc.invoke('storageSetItem', {
                key,
                value
            });
        },
        removeItem (key) {
            return rpc.invoke('storageRemoveItem', key);
        },
        getKeys () {
            return rpc.invoke('storageGetKeys', null);
        },
        clear () {
            return rpc.invoke('storageClear', null);
        },
        watch (callback) {
            const subscription = change$.subscribe(({ event, key })=>{
                callback(event, key);
            });
            return ()=>{
                subscription.unsubscribe();
            };
        }
    };
});

class OffscreenPageFontSettingsService {
    rpc;
    constructor(rpc){
        this.rpc = rpc;
    }
    getGenericFontFamilyFonts() {
        return this.rpc.invoke('getGenericFontFamilyFonts', null);
    }
}

async function setupOffscreenPage() {
    const registration = await navigator.serviceWorker.ready;
    const serviceWorker = registration.active;
    if (!serviceWorker) {
        return;
    }
    const channel = new MessageChannel();
    const rpc = new IOSubjectRPC(OFFSCREEN_RPC_MAGIC, new MessagePortSubject(channel.port1));
    const change$ = new Subject();
    const storage = createStorage({
        driver: UnstorageDriverRpc({
            rpc: rpc,
            change$
        })
    });
    const { oauth } = setupWebExtensionOAuth(storage);
    const $fetch = createFetch(storage, oauth, REGION);
    const env$ = storageObservable(storage, ENV_KEY);
    const logger = new LoggerService(oauth, storage, REGION);
    env$.subscribe((env)=>{
        logger.setEnv(env || 'production');
    });
    const fontSettingsService = new OffscreenPageFontSettingsService(rpc);
    instance.register(STORAGE, {
        useValue: storage
    }).register(FETCH, {
        useValue: $fetch
    }).register(LOGGER, {
        useValue: logger
    }).register(FONT_SETTINGS_SERVICE, {
        useValue: fontSettingsService
    }).register(REGION$1, {
        useValue: REGION
    });
    const uploaderService = instance.resolve(UploaderService);
    const filesService = instance.resolve(FilesService);
    uploaderService.taskStatusChange$.subscribe((event)=>{
        taskStatusBroadcast.postMessage(event);
    });
    rpc.register('uploadTask', async (args)=>{
        await uploaderService.uploadTask(args);
    });
    rpc.register('cancelTask', async (args)=>{
        await uploaderService.cancelTask(args);
    });
    rpc.register('storageChange', (change)=>{
        change$.next(change);
    });
    rpc.register('touchStashFile', (args)=>{
        return filesService.touchStashFile(args);
    });
    rpc.register('markFileStashed', (args)=>{
        return filesService.markFileStashed(args);
    });
    rpc.register('getFileStashStatus', (args)=>{
        return filesService.getFileStashStatus(args);
    });
    serviceWorker.postMessage(OFFSCREEN_CONNECT, [
        channel.port2
    ]);
    window.__db = instance.resolve(RecorderDB);
}

setupOffscreenPage();
